==> webkit2gtk_2.50.0.orig.tar.xz: webkitgtk-2.50.0/Source/WebCore/style/values/filter-effects/StyleFilterReference.cpp <==
/*
 * Copyright (C) 2024 Samuel Weinig <sam@webkit.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "StyleFilterReference.h"

#include "CSSFilterReference.h"
#include "Document.h"
#include "ReferenceFilterOperation.h"

namespace WebCore {
namespace Style {

CSS::FilterReference toCSSFilterReference(Ref<ReferenceFilterOperation> operation, const RenderStyle& style)
{
    return { .url = toCSS(operation->url(), style) };
}

Ref<FilterOperation> createFilterOperation(const CSS::FilterReference& filter, const Document& document, RenderStyle&, const CSSToLengthConversionData&)
{
    auto url = toStyleWithScriptExecutionContext(filter.url, document);

    // FIXME: Unify all the fragment accessing/construction.
    auto fragment = url.resolved.string().startsWith('#')
        ? StringView(url.resolved.string()).substring(1).toAtomString()
        : url.resolved.fragmentIdentifier().toAtomString();

    return ReferenceFilterOperation::create(WTFMove(url), WTFMove(fragment));
}

} // namespace Style
} // namespace WebCore

==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Source/WebCore/style/values/filter-effects/StyleFilterReference.cpp <==
/*
 * Copyright (C) 2024-2025 Samuel Weinig <sam@webkit.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "StyleFilterReference.h"

#include "CSSFilterReference.h"
#include "Document.h"
#include "ReferenceFilterOperation.h"
#include "StyleBuilderState.h"

namespace WebCore {
namespace Style {

CSS::FilterReference toCSSFilterReference(Ref<ReferenceFilterOperation> operation, const RenderStyle& style)
{
    return { .url = toCSS(operation->url(), style) };
}

Ref<FilterOperation> createFilterOperation(const CSS::FilterReference& filter, const BuilderState& state)
{
    auto url = toStyleWithScriptExecutionContext(filter.url, state.document());

    // FIXME: Unify all the fragment accessing/construction.
    auto fragment = url.resolved.string().startsWith('#')
        ? StringView(url.resolved.string()).substring(1).toAtomString()
        : url.resolved.fragmentIdentifier().toAtomString();

    return ReferenceFilterOperation::create(WTFMove(url), WTFMove(fragment));
}

} // namespace Style
} // namespace WebCore
